require 'studio_game/player'

module StudioGame
  describe Player do

    before do
      @health = 150
      @player = Player.new("bob",@health)
    end

    it "has a capitalized name" do
      @player.name.should == "Bob"
    end


    it "has an initial health" do
      @player.health.should == 150
    end

    it "has a string representation" do
      @player.found_treasure(Treasure.new(:hammer, 50))
      @player.found_treasure(Treasure.new(:hammer, 50))

      @player.to_s.should == "I'm Bob with a health of 150 and a score of 253."
    end

    it "computes a score as the sum of its health and length of name" do
      @player.found_treasure(Treasure.new(:hammer, 50))
      @player.found_treasure(Treasure.new(:hammer, 50))
      @player.score.should == 253
    end

    it "increases health by 15 when w00ted" do
      @player.w00t
      @player.health.should == @health + 15 
    end


    it "decreases health by 10 when blammed" do
      @player.blam
      @player.health.should == @health - 10 
    end

    it "yields each found treasure and its total points" do
      @player.found_treasure(Treasure.new(:skillet, 100))
      @player.found_treasure(Treasure.new(:skillet, 100))
      @player.found_treasure(Treasure.new(:hammer, 50))
      @player.found_treasure(Treasure.new(:bottle, 5))
      @player.found_treasure(Treasure.new(:bottle, 5))
      @player.found_treasure(Treasure.new(:bottle, 5))
      @player.found_treasure(Treasure.new(:bottle, 5))
      @player.found_treasure(Treasure.new(:bottle, 5))

      yielded = []
      @player.each_found_treasure do |treasure|
        yielded << treasure
      end

      yielded.should == [
        Treasure.new(:skillet, 200), 
        Treasure.new(:hammer, 50), 
        Treasure.new(:bottle, 25)
      ]
    end

    context "with default health" do
      before do
        @player = Player.new("bob")
      end

      it "should have default health" do
        @player.health.should == 100
      end
    end


    context "with a health greater than 100" do
      before do
        @player = Player.new("bob",150)
      end

      it "is strong" do
        puts @player.strong?
        puts "Hello!"
        @player.strong?.should == true
      end
    end

    context "with a health of 100 or less" do
      before do
        @player = Player.new("bob",100)
      end

      it "is not strong" do
        @player.strong?.should == false
      end
    end

  end
end
